@@ -66,7 +66,7 @@
 #undef R__HAS_DEFAULT_ZSTD  /**/
 #undef R__HAS_CLOUDFLARE_ZLIB /**/
 
-#undef R__HAS_TMVACPU /**/
+#define R__HAS_TMVACPU /**/
 #undef R__HAS_TMVAGPU /**/
 #undef R__HAS_CUDNN /**/
 #undef R__HAS_PYMVA /**/
